"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = exports.displayName = void 0;

var _react = _interopRequireDefault(require("react"));

var _DocsMenuItem = _interopRequireDefault(require("../DocsMenuItem"));

var _PagesGroupDataValidator = _interopRequireDefault(require("../../validators/PagesGroupDataValidator"));

var _routingManager = require("routing-manager");

var _utils = require("../../utils");

var _ = _interopRequireWildcard(require("lodash"));

function _getRequireWildcardCache() { if (typeof WeakMap !== "function") return null; var cache = new WeakMap(); _getRequireWildcardCache = function _getRequireWildcardCache() { return cache; }; return cache; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } if (obj === null || _typeof(obj) !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _toArray(arr) { return _arrayWithHoles(arr) || _iterableToArray(arr) || _unsupportedIterableToArray(arr) || _nonIterableRest(); }

function _toConsumableArray(arr) { return _arrayWithoutHoles(arr) || _iterableToArray(arr) || _unsupportedIterableToArray(arr) || _nonIterableSpread(); }

function _nonIterableSpread() { throw new TypeError("Invalid attempt to spread non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }

function _iterableToArray(iter) { if (typeof Symbol !== "undefined" && Symbol.iterator in Object(iter)) return Array.from(iter); }

function _arrayWithoutHoles(arr) { if (Array.isArray(arr)) return _arrayLikeToArray(arr); }

function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _unsupportedIterableToArray(arr, i) || _nonIterableRest(); }

function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }

function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(n); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }

function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) { arr2[i] = arr[i]; } return arr2; }

function _iterableToArrayLimit(arr, i) { if (typeof Symbol === "undefined" || !(Symbol.iterator in Object(arr))) return; var _arr = []; var _n = true; var _d = false; var _e = undefined; try { for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"] != null) _i["return"](); } finally { if (_d) throw _e; } } return _arr; }

function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }

var displayName = "MaterialDocs-AutoDocsMenu";
exports.displayName = displayName;

var AutoDocsMenu = /*#__PURE__*/_react.default.forwardRef(function AutoDocsMenu(props, ref) {
  var layoutData = props.layoutData;

  var _useChangeRoute = (0, _routingManager.useChangeRoute)(),
      getRouteParams = _useChangeRoute.getRouteParams;

  var _getRouteParams = getRouteParams(),
      page = _getRouteParams.page;

  var _React$useState = _react.default.useState(typeof page === "string" && page.split("/") || []),
      _React$useState2 = _slicedToArray(_React$useState, 2),
      pagePath = _React$useState2[0],
      setPagePath = _React$useState2[1];

  var _React$useState3 = _react.default.useState(null),
      _React$useState4 = _slicedToArray(_React$useState3, 2),
      menu = _React$useState4[0],
      setMenu = _React$useState4[1];

  _react.default.useEffect(function () {
    if (layoutData && layoutData.pages && layoutData.groups) setMenu(recursiveGenerateMenu(layoutData, pagePath));
  }, [layoutData, pagePath]);

  _react.default.useEffect(function () {
    var path = typeof page === "string" && page.split("/") || [];
    setPagePath(path);
  }, [page]);

  if (layoutData && _typeof(layoutData) !== "object") throw new ReferenceError("MaterialDocs: incorrect type of prop layoutData, expected object, got ".concat(_typeof(layoutData)));
  /**
   * sortMenuLevel - returns sorted by order/name the pages/groups data list.
   * @function
   * @param {any[]} items pages/groups data objects list.
   * @return {any[]}
   */

  function sortMenuLevel(items) {
    /**
     * compare - function, designed to compare page/group order/name.
     * @function
     * @param {any} left Left object in comparison.
     * @param {any} right Right object in comparison.
     * @param {string} field Field in input object.
     */
    function compare(left, right, field) {
      if (left[field] > right[field]) return 1;
      if (left[field] === right[field]) return 0;
      return -1;
    }

    var ordered = items.filter(function (item) {
      return item.order;
    }).sort(function (left, right) {
      return compare(left, right, "order");
    });
    var notOrdered = items.filter(function (item) {
      return !item.order;
    }).sort(function (left, right) {
      return compare(left, right, "name");
    });
    var result = [].concat(_toConsumableArray(ordered), _toConsumableArray(notOrdered));
    return result;
  }
  /**
   * recursiveGenerateMenu - recursively creates menu from PagesGroupData data.
   * @function
   * @param {PagesGroupData} layout Layout data of menu.
   * @param {string[]} path Current page path.
   * @return {any}
   */


  function recursiveGenerateMenu(layout, path) {
    if (!Array.isArray(layout.pages)) throw new TypeError("MaterialDocs: incorrect type of layoutData pages, expected any[], got ".concat(_typeof(layout.pages)));
    if (!Array.isArray(layout.groups)) throw new TypeError("MaterialDocs: incorrect type of layoutData groups, expected any[], got ".concat(_typeof(layout.groups)));

    var _path = _toArray(path),
        curPath = _path[0],
        tail = _path.slice(1);

    return /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, sortMenuLevel(layout.groups).map(function (group) {
      return /*#__PURE__*/_react.default.createElement(_DocsMenuItem.default, {
        textPrimary: group.name,
        key: "auto-docs-menu-item-".concat(group.name),
        defaultExpanded: (0, _utils.createRouteFromName)(group.name) === curPath || layout.defaultExpanded
      }, recursiveGenerateMenu(group, tail));
    }), sortMenuLevel(layout.pages).map(function (page) {
      return /*#__PURE__*/_react.default.createElement(_DocsMenuItem.default, {
        page: page.name,
        link: page.link,
        key: "auto-docs-menu-item-".concat(page.name),
        isCurrent: function isCurrent(routeParams, pageRoute, page) {
          return pageRoute === _.last(path);
        }
      });
    }));
  }

  if (!layoutData || !layoutData.pages || !layoutData.groups) return null;
  return menu;
});

AutoDocsMenu.displayName = displayName;
AutoDocsMenu.propTypes = {
  layoutData: _PagesGroupDataValidator.default
};
var _default = AutoDocsMenu;
exports.default = _default;