"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = exports.displayName = void 0;

var _react = _interopRequireDefault(require("react"));

var _commonStyles = require("../../stylesheets/commonStyles");

var _styles = require("./styles");

var _propTypes = _interopRequireDefault(require("prop-types"));

var _styles2 = require("@material-ui/styles");

var _generateMaterialDocsFromMarkdown = _interopRequireDefault(require("../../utils/generateMaterialDocsFromMarkdown"));

var _clsx = _interopRequireDefault(require("clsx"));

var _replaceMarkdownParams = _interopRequireDefault(require("../../utils/replaceMarkdownParams"));

var _utils = require("../../utils");

var _hooks = require("../../hooks");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _unsupportedIterableToArray(arr, i) || _nonIterableRest(); }

function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }

function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(n); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }

function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) { arr2[i] = arr[i]; } return arr2; }

function _iterableToArrayLimit(arr, i) { if (typeof Symbol === "undefined" || !(Symbol.iterator in Object(arr))) return; var _arr = []; var _n = true; var _d = false; var _e = undefined; try { for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"] != null) _i["return"](); } finally { if (_d) throw _e; } } return _arr; }

function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

var displayName = "MaterialDocs-Markdown";
exports.displayName = displayName;

var Markdown = /*#__PURE__*/_react.default.forwardRef(function Markdown(props, ref) {
  var children = props.children,
      className = props.className,
      style = props.style,
      _props$inline = props.inline,
      inline = _props$inline === void 0 ? false : _props$inline,
      _props$data = props.data,
      data = _props$data === void 0 ? {} : _props$data,
      classes = props.classes,
      typographyInheritSize = props.typographyInheritSize,
      locale = props.locale,
      other = _objectWithoutProperties(props, ["children", "className", "style", "inline", "data", "classes", "typographyInheritSize", "locale"]);

  var _useLang = (0, _hooks.useLang)(),
      lang = _useLang.lang;

  var commonClasses = (0, _commonStyles.useCommonStyles)();

  var _React$useState = _react.default.useState(null),
      _React$useState2 = _slicedToArray(_React$useState, 2),
      content = _React$useState2[0],
      setContent = _React$useState2[1];

  _react.default.useEffect(function () {
    if (lang && typeof locale === "string" && typeof (0, _utils.getFieldFromLang)(lang, locale) === "string") {
      var text = (0, _utils.getFieldFromLang)(lang, locale);
      text = (0, _replaceMarkdownParams.default)(text, data, lang);
      setContent((0, _generateMaterialDocsFromMarkdown.default)(text, data, {
        typographyInheritSize: typographyInheritSize
      }));
    } else {
      try {
        var child = "";
        if (children) child = _react.default.Children.map(children, String).join("");
        if (_typeof(data) === "object") child = (0, _replaceMarkdownParams.default)(child, data, lang);
        setContent((0, _generateMaterialDocsFromMarkdown.default)(child, data, {
          typographyInheritSize: typographyInheritSize
        }));
      } catch (error) {
        setContent(null);
        console.error(error);
      }
    }
  }, [children, locale]);

  if (inline) {
    return /*#__PURE__*/_react.default.createElement("span", {
      ref: ref,
      className: (0, _clsx.default)(commonClasses.pageBlock, classes.root, className),
      style: style
    }, content);
  }

  return /*#__PURE__*/_react.default.createElement("div", {
    ref: ref,
    className: (0, _clsx.default)(commonClasses.pageBlock, classes.root, className),
    style: style
  }, content);
});

Markdown.displayName = displayName;
Markdown.propTypes = {
  // MarkdownProps
  inline: _propTypes.default.bool,
  children: _propTypes.default.oneOfType([_propTypes.default.string, _propTypes.default.arrayOf(_propTypes.default.string)]),
  locale: _propTypes.default.string,
  // Stylable
  style: _propTypes.default.object,
  className: _propTypes.default.string,
  classes: _propTypes.default.object // Containerable

};

var _default = (0, _styles2.withStyles)(_styles.styles, {
  name: displayName
})(Markdown);

exports.default = _default;