"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = exports.displayName = void 0;

var _react = _interopRequireDefault(require("react"));

var _styles = require("./styles");

var _commonStyles = require("../../stylesheets/commonStyles");

var _Typography = _interopRequireDefault(require("@material-ui/core/Typography"));

var _Divider = _interopRequireDefault(require("@material-ui/core/Divider"));

var _Link = _interopRequireDefault(require("@material-ui/icons/Link"));

var _propTypes = _interopRequireDefault(require("prop-types"));

var _clsx = _interopRequireDefault(require("clsx"));

var _useTags2 = _interopRequireDefault(require("../../hooks/useTags"));

var _getTextFromChildren = _interopRequireDefault(require("../../utils/getTextFromChildren"));

var _styles2 = require("@material-ui/styles");

var _getElementOffsetSum2 = _interopRequireDefault(require("../../utils/getElementOffsetSum"));

var _createRouteFromName = _interopRequireDefault(require("../../utils/createRouteFromName"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _unsupportedIterableToArray(arr, i) || _nonIterableRest(); }

function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }

function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(n); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }

function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) { arr2[i] = arr[i]; } return arr2; }

function _iterableToArrayLimit(arr, i) { if (typeof Symbol === "undefined" || !(Symbol.iterator in Object(arr))) return; var _arr = []; var _n = true; var _d = false; var _e = undefined; try { for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"] != null) _i["return"](); } finally { if (_d) throw _e; } } return _arr; }

function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

var displayName = "MaterialDocs-Tagable";
exports.displayName = displayName;

var Tagable = /*#__PURE__*/_react.default.forwardRef(function Tagable(props, ref) {
  var children = props.children,
      _props$noTag = props.noTag,
      noTag = _props$noTag === void 0 ? false : _props$noTag,
      _props$variant = props.variant,
      variant = _props$variant === void 0 ? "h1" : _props$variant,
      style = props.style,
      className = props.className,
      classes = props.classes,
      _props$noDivider = props.noDivider,
      noDivider = _props$noDivider === void 0 ? false : _props$noDivider,
      other = _objectWithoutProperties(props, ["children", "noTag", "variant", "style", "className", "classes", "noDivider"]);

  var typographyClasses = {
    h1: classes.h1,
    h2: classes.h2,
    h3: classes.h3,
    h4: classes.h4,
    h5: classes.h5,
    h6: classes.h6
  };
  var commonClasses = (0, _commonStyles.useCommonStyles)();

  var _useTags = (0, _useTags2.default)(),
      setTag = _useTags.setTag,
      removeTag = _useTags.removeTag,
      tags = _useTags.tags;

  var _React$useState = _react.default.useState(0),
      _React$useState2 = _slicedToArray(_React$useState, 2),
      topOffset = _React$useState2[0],
      setTopOffset = _React$useState2[1];

  var id = _react.default.useRef(other.id || (0, _createRouteFromName.default)((0, _getTextFromChildren.default)(children, 6)));

  var prevId = _react.default.useRef(id.current);

  var aref = _react.default.useRef(null);

  _react.default.useEffect(function () {
    prevId.current = id.current;
    id.current = other.id || (0, _createRouteFromName.default)((0, _getTextFromChildren.default)(children, 6));
    if (!noTag && id.current) setTag(id.current, {
      label: children,
      ref: aref,
      topOffset: topOffset
    });
    if (!noTag && !id.current) prevId.current && removeTag(prevId.current);
    return function () {
      if (!noTag) {
        id.current && removeTag(id.current);
      }
    };
  }, [aref.current, topOffset, id.current, children]);

  _react.default.useEffect(function () {
    var _getElementOffsetSum = (0, _getElementOffsetSum2.default)(aref.current),
        top = _getElementOffsetSum.top;

    setTopOffset(top);
  }, [aref.current]);

  if (!id.current) return null;
  return /*#__PURE__*/_react.default.createElement("div", {
    className: (0, _clsx.default)(commonClasses.pageBlock, classes.root, className),
    style: style,
    ref: ref
  }, /*#__PURE__*/_react.default.createElement("div", {
    className: classes.anchor,
    id: noTag ? undefined : id.current
  }, /*#__PURE__*/_react.default.createElement("div", {
    className: classes.container
  }, /*#__PURE__*/_react.default.createElement(_Typography.default, {
    variant: variant,
    classes: typographyClasses,
    className: classes.typography
  }, /*#__PURE__*/_react.default.createElement("div", {
    className: classes.textBlock
  }, children), !noDivider && /*#__PURE__*/_react.default.createElement(_Divider.default, {
    className: classes.divider
  })), !noTag && /*#__PURE__*/_react.default.createElement("a", {
    href: "#".concat(id.current),
    className: classes.tagHook,
    ref: aref
  }, /*#__PURE__*/_react.default.createElement(_Link.default, {
    className: classes.anchorIcon
  })))));
});

Tagable.displayName = displayName;
Tagable.propTypes = {
  // Stylable
  style: _propTypes.default.object,
  className: _propTypes.default.string,
  classes: _propTypes.default.object,
  // Containerable
  children: _propTypes.default.node
};

var _default = (0, _styles2.withStyles)(_styles.styles, {
  name: displayName
})(Tagable);

exports.default = _default;