"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = replaceMarkdownParams;

var _react = _interopRequireDefault(require("react"));

var _index = require("./index");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function replaceMarkdownParams(markdown) {
  var storage = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
  var lang = arguments.length > 2 ? arguments[2] : undefined;

  /**
   * replaceNextParam - replaces next found variable with value from storage.
   * @function
   * @param {{current: string}} ref Ref object with markdown based text inside.
   * @return {boolean}
   */
  function replaceNextParam(ref) {
    var start = ref.current.indexOf("&&");
    if (start < 0) return false;
    var end = start + 2;

    while (end < ref.current.length && ref.current[end].match(/^[0-9a-zA-Z]+$/)) {
      end++;
    }

    var variable = ref.current.slice(start, end);

    if (variable.length <= 2) {
      ref.current = ref.current.replace("&&", "```incorrect variable```");
      return false;
    }

    var replacer = storage[variable.slice(2)];
    ref.current = ref.current.replace(variable, replacer ? String(replacer) : "");
    return true;
  }

  function replaceNextLocale(ref) {
    if (!lang) return false;
    var start = ref.current.indexOf("&{");
    if (start < 0) return false;
    var end = ref.current.indexOf("}&", start);
    if (end < 0) return false;
    var variable = ref.current.slice(start, end + 2);
    var path = variable.slice(2, variable.length - 2);
    var locale = (0, _index.getFieldFromLang)(lang, path);

    if (typeof locale !== "string") {
      ref.current = ref.current.replace(variable, "__incorrect locale(".concat(path && "```" + path + "```", ")__"));
      return true;
    }

    ref.current = ref.current.replace(variable, locale);
    return true;
  }

  if (lang && _typeof(lang) !== "object") throw new TypeError("MaterialDocs: invalid param \"lang\", expected \"Lang\" got \"".concat(_typeof(lang), "\""));
  if (lang && _typeof(lang.locale) !== "object") throw new TypeError("MaterialDocs: invalid param \"lang.locale\", expected \"object\" got \"".concat(_typeof(lang.object), "\""));
  if (typeof markdown !== "string") throw new TypeError("MaterialDocs: invalid param \"markdown\", expected \"string\" got \"".concat(_typeof(markdown), "\""));
  if (_typeof(storage) !== "object") throw new TypeError("MaterialDocs: invalid param \"storage\", expected \"object\" got \"".concat(_typeof(storage), "\""));

  var ref = /*#__PURE__*/_react.default.createRef();

  ref.current = markdown;

  while (replaceNextParam(ref) || replaceNextLocale(ref)) {}

  return ref.current;
}